FlutterTencentLocationPlatform class abstract

Inheritance
  • Object
  • PlatformInterface
  • FlutterTencentLocationPlatform
Implementers

Constructors

FlutterTencentLocationPlatform()
Constructs a FlutterTencentLocationPlatform.

Properties

hashCode → int
The hash code for this object.
no setterinherited
locationController ↔ LocationController
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

getLocation(int interval) → Future<Location?>
getPlatformVersion() → Future<String?>
init(String key) → Future<String>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setUserAgreePrivacy() → void
stopLocation() → void
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

instance ↔ FlutterTencentLocationPlatform
The default instance of FlutterTencentLocationPlatform to use.
getter/setter pair