Location class

Constructors

Location()

Properties

address ↔ String?
地址
getter/setter pair
altitude ↔ double?
海拔
getter/setter pair
area ↔ String?
getter/setter pair
city ↔ String?
getter/setter pair
cityCode ↔ String?
getter/setter pair
code ↔ int
code值说明
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
latitude ↔ double?
纬度
getter/setter pair
longitude ↔ double?
经度
getter/setter pair
name ↔ String?
地名
getter/setter pair
province ↔ String?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

getAddress() → String?
getAltitude() → double?
getCityCode() → String?
getCode() → int?
getLatitude() → double?
getLongitude() → double?
getName() → String?
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited